==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-about/lxqt-about_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>AboutDialogPrivate</name>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.cpp" line="83"/>
        <source>Version: %1</source>
        <translation>版本：%1</translation>
    </message>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.cpp" line="96"/>
        <source>Advanced, easy-to-use, and fast desktop environment based on Qt technologies.</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>基于 Qt 技术的高级、易用、快速的桌面环境</translation>
    </message>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.cpp" line="98"/>
        <source>LXQt would not have been possible without the &lt;a %1&gt;Razor-qt&lt;/a&gt; project and its many contributors.</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copyright: %1-%2 %3</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">版权所有：%1-%2 %3</translation>
    </message>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.cpp" line="100"/>
        <source>Copyright: © %1-%2 %3</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.cpp" line="102"/>
        <source>Homepage: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>主页：%1</translation>
    </message>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.cpp" line="104"/>
        <source>License: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>协议：%1</translation>
    </message>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.cpp" line="114"/>
        <source>LXQt is developed by the &lt;a %1&gt;LXQt Team and contributors&lt;/a&gt;.</source>
        <comment>About dialog, &apos;Authors&apos; tab text</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.cpp" line="116"/>
        <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
        <comment>About dialog, &apos;Authors&apos; tab text</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.cpp" line="133"/>
        <source>Special thanks to:</source>
        <comment>About dialog, &apos;Thanks&apos; tab text</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.cpp" line="140"/>
        <source>LXQt is translated into many languages thanks to the work of the translation teams all over the world.</source>
        <comment>About dialog, &apos;Translations&apos; tab text</comment>
        <translation>LXQt 已被翻译成多种语言，特别感谢来自世界各地的翻译团队的努力。</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="obsolete">是</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="obsolete">否</translation>
    </message>
    <message>
        <source>&lt;b&gt;LXQt Desktop Toolbox - Technical Info&lt;/b&gt;</source>
        <translation type="obsolete">&lt;b&gt;LXQt 桌面工具箱 - 技术信息&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Version</source>
        <translation type="obsolete">版本</translation>
    </message>
    <message>
        <source>Qt</source>
        <translation type="obsolete">Qt</translation>
    </message>
    <message>
        <source>Debug Build</source>
        <translation type="obsolete">调试版本</translation>
    </message>
    <message>
        <source>System Configuration</source>
        <translation type="obsolete">系统配置</translation>
    </message>
    <message>
        <source>Share Directory</source>
        <translation type="obsolete">共享目录</translation>
    </message>
    <message>
        <source>Translations</source>
        <comment>About dialog, Tab title</comment>
        <translation type="obsolete">翻译</translation>
    </message>
    <message>
        <source>&lt;b&gt;User Directories&lt;/b&gt;</source>
        <translation type="obsolete">&lt;b&gt;用户目录&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Xdg Data Home</source>
        <translation type="obsolete">Xdg 数据位置</translation>
    </message>
    <message>
        <source>Xdg Config Home</source>
        <translation type="obsolete">Xdg 配置文件</translation>
    </message>
    <message>
        <source>Xdg Data Dirs</source>
        <translation type="obsolete">Xdg 数据目录</translation>
    </message>
    <message>
        <source>Xdg Cache Home</source>
        <translation type="obsolete">Xdg 缓存目录</translation>
    </message>
    <message>
        <source>Xdg Runtime Home</source>
        <translation type="obsolete">Xdg 运行时目录</translation>
    </message>
    <message>
        <source>Xdg Autostart Dirs</source>
        <translation type="obsolete">Xdg 开机启动目录</translation>
    </message>
    <message>
        <source>Xdg Autostart Home</source>
        <translation type="obsolete">Xdg 开机启动文件</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.ui" line="14"/>
        <source> About LXQt</source>
        <translation>关于LXQt</translation>
    </message>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.ui" line="66"/>
        <source>About</source>
        <comment>About dialog, Tab title </comment>
        <translation>关于</translation>
    </message>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.ui" line="83"/>
        <source>Authors</source>
        <comment>About dialog, Tab title</comment>
        <translation>作者</translation>
    </message>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.ui" line="100"/>
        <source>Thanks</source>
        <comment>About dialog, Tab title</comment>
        <translation>致谢</translation>
    </message>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.ui" line="117"/>
        <source>Translations</source>
        <comment>About dialog, Tab title</comment>
        <translation>翻译</translation>
    </message>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.ui" line="134"/>
        <source>Technical Info</source>
        <comment>About dialog, Tab title</comment>
        <translation>技术信息</translation>
    </message>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.ui" line="165"/>
        <source>Copy to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-about/lxqt-about_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>AboutDialogPrivate</name>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.cpp" line="83"/>
        <source>Version: %1</source>
        <translation>版本：%1</translation>
    </message>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.cpp" line="96"/>
        <source>Advanced, easy-to-use, and fast desktop environment based on Qt technologies.</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>基于 Qt 技术的高级、易用、快速的桌面环境</translation>
    </message>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.cpp" line="98"/>
        <source>LXQt would not have been possible without the &lt;a %1&gt;Razor-qt&lt;/a&gt; project and its many contributors.</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="unfinished">LXQT的成功离不开&lt;a %1&gt;Razor-qt&lt;/a&gt;项目和它的众多贡献者</translation>
    </message>
    <message>
        <source>Copyright: %1-%2 %3</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">版权所有：%1-%2 %3</translation>
    </message>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.cpp" line="100"/>
        <source>Copyright: © %1-%2 %3</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="unfinished">版权所有: © %1-%2 %3</translation>
    </message>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.cpp" line="102"/>
        <source>Homepage: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>主页：%1</translation>
    </message>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.cpp" line="104"/>
        <source>License: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>协议：%1</translation>
    </message>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.cpp" line="114"/>
        <source>LXQt is developed by the &lt;a %1&gt;LXQt Team and contributors&lt;/a&gt;.</source>
        <comment>About dialog, &apos;Authors&apos; tab text</comment>
        <translation type="unfinished">LXQT由&lt;a %1&gt;LXQt团队以及众多贡献者开发&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.cpp" line="116"/>
        <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
        <comment>About dialog, &apos;Authors&apos; tab text</comment>
        <translation type="unfinished">假如你对我们的开发工作有兴趣， &lt;a %1&gt;加入我们吧&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.cpp" line="133"/>
        <source>Special thanks to:</source>
        <comment>About dialog, &apos;Thanks&apos; tab text</comment>
        <translation type="unfinished">特别感谢：</translation>
    </message>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.cpp" line="140"/>
        <source>LXQt is translated into many languages thanks to the work of the translation teams all over the world.</source>
        <comment>About dialog, &apos;Translations&apos; tab text</comment>
        <translation>LXQt 已被翻译成多种语言，特别感谢来自世界各地的翻译团队的努力。</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="obsolete">是</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="obsolete">否</translation>
    </message>
    <message>
        <source>&lt;b&gt;LXQt Desktop Toolbox - Technical Info&lt;/b&gt;</source>
        <translation type="obsolete">&lt;b&gt;LXQt 桌面工具箱 - 技术信息&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Version</source>
        <translation type="obsolete">版本</translation>
    </message>
    <message>
        <source>Qt</source>
        <translation type="obsolete">Qt</translation>
    </message>
    <message>
        <source>Debug Build</source>
        <translation type="obsolete">调试版本</translation>
    </message>
    <message>
        <source>System Configuration</source>
        <translation type="obsolete">系统配置</translation>
    </message>
    <message>
        <source>Share Directory</source>
        <translation type="obsolete">共享目录</translation>
    </message>
    <message>
        <source>Translations</source>
        <comment>About dialog, Tab title</comment>
        <translation type="obsolete">翻译</translation>
    </message>
    <message>
        <source>&lt;b&gt;User Directories&lt;/b&gt;</source>
        <translation type="obsolete">&lt;b&gt;用户目录&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Xdg Data Home</source>
        <translation type="obsolete">Xdg 数据位置</translation>
    </message>
    <message>
        <source>Xdg Config Home</source>
        <translation type="obsolete">Xdg 配置文件</translation>
    </message>
    <message>
        <source>Xdg Data Dirs</source>
        <translation type="obsolete">Xdg 数据目录</translation>
    </message>
    <message>
        <source>Xdg Cache Home</source>
        <translation type="obsolete">Xdg 缓存目录</translation>
    </message>
    <message>
        <source>Xdg Runtime Home</source>
        <translation type="obsolete">Xdg 运行时目录</translation>
    </message>
    <message>
        <source>Xdg Autostart Dirs</source>
        <translation type="obsolete">Xdg 开机启动目录</translation>
    </message>
    <message>
        <source>Xdg Autostart Home</source>
        <translation type="obsolete">Xdg 开机启动文件</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.ui" line="14"/>
        <source> About LXQt</source>
        <translation>关于LXQt</translation>
    </message>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.ui" line="66"/>
        <source>About</source>
        <comment>About dialog, Tab title </comment>
        <translation>关于</translation>
    </message>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.ui" line="83"/>
        <source>Authors</source>
        <comment>About dialog, Tab title</comment>
        <translation>作者</translation>
    </message>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.ui" line="100"/>
        <source>Thanks</source>
        <comment>About dialog, Tab title</comment>
        <translation>致谢</translation>
    </message>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.ui" line="117"/>
        <source>Translations</source>
        <comment>About dialog, Tab title</comment>
        <translation>翻译</translation>
    </message>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.ui" line="134"/>
        <source>Technical Info</source>
        <comment>About dialog, Tab title</comment>
        <translation>技术信息</translation>
    </message>
    <message>
        <location filename="../../aboutdialog/lxqtaboutdialog.ui" line="165"/>
        <source>Copy to clipboard</source>
        <translation type="unfinished">复制</translation>
    </message>
</context>
</TS>
